Any Drug Missing In Regimens?
anyDrugMissingInRegimens.RdThis function checks for each patient if there is a drug missing in regimens. It uses the anyUncoveredDrugs function to check for each patient separately.
anyDrugMissingInRegimens.RdThis function checks for each patient if there is a drug missing in regimens. It uses the anyUncoveredDrugs function to check for each patient separately.