Map concept IDs to concept names Reads a line-delimited list of concept IDs and returns the matching concept names from `regimens_env$concepts` already in scope.
conceptToList.RdMap concept IDs to concept names Reads a line-delimited list of concept IDs and returns the matching concept names from `regimens_env$concepts` already in scope.