Skip to contents

This function generates a summary report for the processed alignment data. It checks if regimens start after the first drug, if regimens end before the last drug, if consecutive regimens are the same, and if there are any uncovered drugs for each patient.

Usage

generateSummaryReport(pa, ra, regimens)

Arguments

pa

Processed alignment data with personID and t_start.