Skip to contents

Load regimens for a given condition

Usage

loadRegimens(
  condition = "all",
  absolute = NULL,
  mapping = list(lungCancer = c("Thoraic Oncology", "Thoraic Oncology"), multipleMyeloma
    = c("Multiple Myeloma")),
  concept_file = NULL,
  ignore_default_list = FALSE
)

Arguments

condition

A string indicating which regimen set to load

absolute

Path to system regimen to use as reference Presently, the only condition fully mapped are lungCancer and multiple myeloma Edit: all conditions supported matching a name OR providing a mapping, see example

mapping

A named list of user provids condition to maping