Plots a full alignment output
plotAlignment.RdFor each patient separately, plot drug exposures and aligned regimens over time
Arguments
- pa
A patient alignment dataframe created by processAlignments() or generateRawAlignments()
- regimens
A regimen dataframe, containing required regimen column shortStrings. Used to determine which drugs are missing in regimens for summary report and plot.
- collapse_regimens
A boolean indicating whether to collapse regimens into a single row