Skip to contents

Plots a plot displaying the observed regimen length distribution for a given regimen, or two given regimens processed output

Usage

plotRegimenLengthDistribution(pa, components = NULL, top_n = 6)

Arguments

pa

Patients alignments dataframe created by processAlignments

components

A set of regimens of interest

top_n

Top n most frequent regimens to plot. Ignored if components provided. Default is 6

Value

plot - A ggplot object