Skip to contents

Plots a sankey diagram displaying the flow between first, second and third regimen eras

Usage

plotSankey(processedEras, regGroups, saveLocation = NA, fileName = "Network")

Arguments

processedEras

An output dataframe created by calculateEras

regGroups

A dataframe indicating how to group regimens

saveLocation

A file directory location where files may be saved

fileName

A filename prefix for saved files