Skip to contents

Postprocess alignment output

Usage

postprocessSinglePatientDF(
  output,
  regimenCombine = 28,
  discontinuationTime = regimenCombine
)

Arguments

output

An output dataframe created by align()

regimenCombine

Allowed number of days between two instances of the same regimen before

discontinuationTime

The number of days to use to indicate treatment discontinuation treshold for line of treatment annotation

Value

df - A data.frame object