Global Variable Warnings These warnings serve no purpose and since tidyr 1.2.0 the .data pronoun is not used in select() and unnest(), thus leading to these warnings being erroneously generated
regName.RdGlobal Variable Warnings These warnings serve no purpose and since tidyr 1.2.0 the .data pronoun is not used in select() and unnest(), thus leading to these warnings being erroneously generated