Load regimens for a given condition
loadRegimens.RdLoad regimens for a given condition
Arguments
- condition
A string indicating which regimen set to load
- absolute
Path to system regimen to use as reference Presently, the only condition fully mapped are lungCancer and multiple myeloma Edit: all conditions supported matching a name OR providing a mapping, see example
- mapping
A named list of user provids condition to maping