Plots a sankey diagram displaying the flow between first, second and third regimen eras
plotSankey.RdPlots a sankey diagram displaying the flow between first, second and third regimen eras
plotSankey.RdPlots a sankey diagram displaying the flow between first, second and third regimen eras