Post-process alignment output
processAlignments.RdPerform post-processing on a data frame of raw alignment results. Three main steps are performed: 1. Remove overlaps between regimens 2. Combine regimens 3. Calculate additional time-based metrics and line of treatment.
Arguments
- ra
Raw alignments. An output dataframe produced by generateRawAlignments()
- regimenCombine
The numeric value of days allowed between regimens of the same name before they are collapsed/summarised into a single regimen
- discontinuationTime
The number of days to use to indicate treatment discontinuation treshold for line of treatment annotation. Default is the same as regimenCombine, but can be set higher to allow for longer gaps between lines of treatment.